==> v1.1.zip: zenidrv-g203/README.md <==
# Logitech G203 Prodigy/LightSync Mouse LED control (GUI)

Allows you to control the LED lighting of your G203 Prodigy or G203 LightSync Mouse programmatically. \
Inspired by and based on [g810-led](https://github.com/MatMoul/g810-led).

## Requirements

- Python 3.5+
- PyUSB 1.0.2+
- Zenity
- **Root privileges**

## Downloads:

## Installation:

1) Clone the repository: `git clone https://github.com/q3aql/zenidrv-g203`
2) Install dependencies: `sudo apt-get install python3 python3-usb zenity coreutils`
3) Change directory: `cd zenidrv-g203`
4) Install as root: `sudo make install`

## Usage (GUI):

Open application from menu or run the following command as root:

```
 $ sudo zenidrv-g203
```

<img src="https://raw.githubusercontent.com/q3aql/zenidrv-g203/master/images/menu-zenity.png" width="876" />

## Usage (CLI):

```
Usage:
    sudo g203-led.py [lightsync] solid {color} - Solid color mode
    sudo g203-led.py [lightsync] cycle [{rate} [{brightness}]] - Cycle through all colors
    sudo g203-led.py [lightsync] breathe {color} [{rate} [{brightness}]] - Single color breathing
    sudo g203-led.py [lightsync] intro {on|off} - Enable/disable startup effect
    sudo g203-led.py [lightsync] dpi {dpi} - Set mouse dpi

Arguments:
    Color: RRGGBB (RGB hex value)
    Rate: 100-60000 (Number of milliseconds. Default: 10000ms)
    Brightness: 0-100 (Percentage. Default: 100%)
    DPI: 200-8000 (Prodigy), 50-8000 (Lightsync)

Additional features for G203 LightSync:
    sudo g203-led.py lightsync triple {color color color} - Sets all 3 colors from left to right.
    sudo g203-led.py lightsync wave {rate} [{brightness} [{direction}]] - Like cycle but appears to move right or left.
    sudo g203-led.py lightsync blend [{rate} [{brightness}]] - Like breathe with the side colors changing after some delay.

    Direction is either "left" or "right". Default: right).

Note that the lightsync setting will not persist.
There is onboard memory for persistence but it is not used by this script.
```

==> v1.2.zip: zenidrv-g203/README.md <==
# Logitech G203 Prodigy/LightSync Mouse LED control (GUI)

Allows you to control the LED lighting of your G203 Prodigy or G203 LightSync Mouse programmatically. \
Inspired by and based on [g810-led](https://github.com/MatMoul/g810-led).

## Requirements

- Python 3.5+
- PyUSB 1.0.2+
- Zenity
- Xterm (generally installed in the system)
- bc (generally installed in the system)
- **Root privileges**

### Downloads:

  * [zenidrv-g203-v1.2.tar.gz](https://github.com/q3aql/zenidrv-g203/releases/download/v1.2/zenidrv-g203-v1.2.tar.gz) - Generic package.
  * [zenidrv-g203-v1.2.deb](https://github.com/q3aql/zenidrv-g203/releases/download/v1.2/zenidrv-g203-v1.2.deb) - Debian based package.
  * [zenidrv-g203-1.2.rpm](https://github.com/q3aql/zenidrv-g203/releases/download/v1.2/zenidrv-g203-1.2.rpm) - RedHat/Fedora based package.

## Installation:

1) Clone the repository: `git clone https://github.com/q3aql/zenidrv-g203`
2) Install dependencies: `sudo apt-get install python3 python3-usb zenity coreutils bc xterm`
3) Change directory: `cd zenidrv-g203`
4) Install as root: `sudo make install`

## Usage (GUI):

Open application from menu or run the following command as root:

```
 $ sudo zenidrv-g203
```

<img src="https://raw.githubusercontent.com/q3aql/zenidrv-g203/master/images/menu-zenity.png" width="876" />

## Usage (CLI):

```
Usage:
    sudo g203-led.py [lightsync] solid {color} - Solid color mode
    sudo g203-led.py [lightsync] cycle [{rate} [{brightness}]] - Cycle through all colors
    sudo g203-led.py [lightsync] breathe {color} [{rate} [{brightness}]] - Single color breathing
    sudo g203-led.py [lightsync] intro {on|off} - Enable/disable startup effect
    sudo g203-led.py [lightsync] dpi {dpi} - Set mouse dpi

Arguments:
    Color: RRGGBB (RGB hex value)
    Rate: 100-60000 (Number of milliseconds. Default: 10000ms)
    Brightness: 0-100 (Percentage. Default: 100%)
    DPI: 200-8000 (Prodigy), 50-8000 (Lightsync)

Additional features for G203 LightSync:
    sudo g203-led.py lightsync triple {color color color} - Sets all 3 colors from left to right.
    sudo g203-led.py lightsync wave {rate} [{brightness} [{direction}]] - Like cycle but appears to move right or left.
    sudo g203-led.py lightsync blend [{rate} [{brightness}]] - Like breathe with the side colors changing after some delay.

    Direction is either "left" or "right". Default: right).

Note that the lightsync setting will not persist.
There is onboard memory for persistence but it is not used by this script.
```
